==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/instance/impl/ComponentInstanceContainerSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.instance.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.instance.ComponentInstanceContainer;
import io.ciera.tool.sql.ooaofooa.instance.ComponentInstanceContainerSet;
import io.ciera.tool.sql.ooaofooa.instance.ComponentInstanceSet;
import io.ciera.tool.sql.ooaofooa.instance.impl.ComponentInstanceSetImpl;

import java.util.Arrays;
import java.util.List;


public class ComponentInstanceContainerSetImpl extends InstanceSet<ComponentInstanceContainerSet,ComponentInstanceContainer> implements ComponentInstanceContainerSet {

    // attributes
    @Override
    public void setContainer_ID( UniqueId ref_Container_ID ) throws XtumlException {
        for ( ComponentInstanceContainer componentinstancecontainer : this ) componentinstancecontainer.setContainer_ID( ref_Container_ID );
    }


    // selections
    @Override
    public ComponentInstanceSet R2974_ComponentInstance() throws XtumlException {
        ComponentInstanceSet componentinstanceset = new ComponentInstanceSetImpl();
        for ( ComponentInstanceContainer componentinstancecontainer : this ) componentinstanceset.add( componentinstancecontainer.R2974_ComponentInstance() );
        return componentinstanceset;
    }
    @Override
    public ComponentInstanceSet R2975_ComponentInstance() throws XtumlException {
        ComponentInstanceSet componentinstanceset = new ComponentInstanceSetImpl();
        for ( ComponentInstanceContainer componentinstancecontainer : this ) componentinstanceset.addAll( componentinstancecontainer.R2975_ComponentInstance() );
        return componentinstanceset;
    }


    @Override
    public ComponentInstanceContainer nullElement() {
        return ComponentInstanceContainerImpl.EMPTY_COMPONENTINSTANCECONTAINER;
    }

    @Override
    public ComponentInstanceContainerSet emptySet() {
      return new ComponentInstanceContainerSetImpl();
    }

    @Override
    public ComponentInstanceContainerSet value() {
        return this;
    }

    @Override
    public List<ComponentInstanceContainer> elements() {
        return Arrays.asList(toArray(new ComponentInstanceContainer[0]));
    }

}

==> tool-sql-2.2.0-sources.jar: io/ciera/tool/sql/ooaofooa/instance/impl/ComponentInstanceContainerSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.instance.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.instance.ComponentInstanceContainer;
import io.ciera.tool.sql.ooaofooa.instance.ComponentInstanceContainerSet;
import io.ciera.tool.sql.ooaofooa.instance.ComponentInstanceSet;
import io.ciera.tool.sql.ooaofooa.instance.impl.ComponentInstanceSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class ComponentInstanceContainerSetImpl extends InstanceSet<ComponentInstanceContainerSet,ComponentInstanceContainer> implements ComponentInstanceContainerSet {

    public ComponentInstanceContainerSetImpl() {
    }

    public ComponentInstanceContainerSetImpl(Comparator<? super ComponentInstanceContainer> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setContainer_ID( UniqueId ref_Container_ID ) throws XtumlException {
        for ( ComponentInstanceContainer componentinstancecontainer : this ) componentinstancecontainer.setContainer_ID( ref_Container_ID );
    }


    // selections
    @Override
    public ComponentInstanceSet R2974_ComponentInstance() throws XtumlException {
        ComponentInstanceSet componentinstanceset = new ComponentInstanceSetImpl();
        for ( ComponentInstanceContainer componentinstancecontainer : this ) componentinstanceset.add( componentinstancecontainer.R2974_ComponentInstance() );
        return componentinstanceset;
    }
    @Override
    public ComponentInstanceSet R2975_ComponentInstance() throws XtumlException {
        ComponentInstanceSet componentinstanceset = new ComponentInstanceSetImpl();
        for ( ComponentInstanceContainer componentinstancecontainer : this ) componentinstanceset.addAll( componentinstancecontainer.R2975_ComponentInstance() );
        return componentinstanceset;
    }


    @Override
    public ComponentInstanceContainer nullElement() {
        return ComponentInstanceContainerImpl.EMPTY_COMPONENTINSTANCECONTAINER;
    }

    @Override
    public ComponentInstanceContainerSet emptySet() {
      return new ComponentInstanceContainerSetImpl();
    }

    @Override
    public ComponentInstanceContainerSet emptySet(Comparator<? super ComponentInstanceContainer> comp) {
      return new ComponentInstanceContainerSetImpl(comp);
    }

    @Override
    public ComponentInstanceContainerSet value() {
        return this;
    }

    @Override
    public List<ComponentInstanceContainer> elements() {
        return Arrays.asList(toArray(new ComponentInstanceContainer[0]));
    }

}
